  repos <- paste0('/esarchive/exp/ecmwf/system4_m1/6hourly/',
                  '$var$/$var$_$sdate$.nc')
  
  system4 <- Start(dat = repos,
                   var = 'tas',
                   sdate = sapply(1994, function(x) paste0(x, sprintf('%02d', 5:12), '01')),
                   time = indices(seq(1, 124, 4)),  #first time step per day
                   ensemble = 'all',
                   latitude = indices(1:10),
                   longitude = indices(1:10),
                   return_vars = list(latitude = NULL,
                                      longitude = NULL,
                                      time = c('sdate')))

#-------- Check exp data -----------
 attr(system4, 'Dimensions')
#      dat       var     sdate      time  ensemble  latitude longitude 
#        1         1         8        31        51        10        10 
#-----------------------------------

# ------- retrieve the attributes for obs load-in ----------
  dates <- attr(system4, 'Variables')$common$time
#> dim(dates)
#sdate  time 
#    8    31 
  dates_file <- sort(unique(gsub('-', '', sapply(as.character(dates),
  substr, 1, 7))))
#> dates_file
#[1] "199405" "199406" "199407" "199408" "199409" "199410" "199411" "199412"
# -----------------------------------------------------------
  
  repos_obs <- paste0('/esarchive/recon/ecmwf/erainterim/6hourly/',
                      '$var$/$var$_$file_date$.nc')
  erai <-    Start(dat = repos_obs,
                   var = 'tas',
                   file_date = dates_file,
                   time = values(dates),  #use dates from exp
                   latitude = indices(1:10),
                   longitude = indices(1:10),
                   time_var = 'time',
                   #because time is assigned by 'values', set the tolerance to avoid too distinct match
                   time_tolerance = as.difftime(1, units = 'hours'), 
                   #time is defined by dates, which dimension is [sdate = 8, time = 200]
                   time_across = 'file_date',  
                   return_vars = list(latitude = NULL,
                                      longitude = NULL,
                                      time = 'file_date'),
                   #combine time and file_date
                   merge_across_dims = TRUE,
                   #split time, because it is two-dimensional
                   split_multiselected_dims = TRUE)

#------- Check erai -----------
 attr(erai, 'Dimensions')
#      dat       var     sdate      time  latitude longitude 
#        1         1         8        31        10        10 
#------------------------------
